@@ -11,7 +11,7 @@ from shade import ShadeLocal
     'image/photo-3.jpg',
     'image/exr-hdr-weird/rgba_half.exr',
 ])
-def test_clap_audio_job(
+def test_ocio(
         demo_file_path,
         backend: ShadeLocal,
         tmp_path
